@@ -17,7 +17,7 @@ log.setLevel(logging.DEBUG)
 
 def parser_person(link, wbsite):
     try:
-        html = f.get_html(link)
+        html = f.get_html(link["link"])
         soup = BeautifulSoup(html.text, 'html.parser')
         soup = soup.find('div', class_='b-content-body js-content-body')
         try:
@@ -27,6 +27,8 @@ def parser_person(link, wbsite):
         name = soup.find('div', class_='b-card-title-container')
         work = name.find('h3', class_='b-card-title b-card-post').get_text().lower()
         name = name.find('h2').get_text().replace('.', ' ')
+        if name == "" or name == None:
+            name = link["name"].replace(".", " ")
         name = f.get_name(name)
         date = soup.find_all('dl', class_='b-card-info-block g-clrfix')
         try:
@@ -56,7 +58,7 @@ def parser_person(link, wbsite):
             'first_name': name[1],
             'middle_name': name[2],
             'last_name': name[0],
-            'link': link,
+            'link': link["link"],
             'bday': 1,
             'bmonth': 1,
             'byear': 1901,
@@ -68,7 +70,7 @@ def parser_person(link, wbsite):
             'first_name': name[1],
             'middle_name': name[2],
             'last_name': name[0],
-            'link': link,
+            'link': link["link"],
             'bday': date['day'],
             'bmonth': date['month'],
             'byear': date['year'],
@@ -116,7 +118,7 @@ def parser_people_links(link):
         for sou in soup1:
             sou = sou.find('a', class_='item_link')
             if sou != None:
-                links.append(link[:-1] + sou.get('href'))
+                links.append({"link":link[:-1] + sou.get('href'), "name": sou.get_text()})
     else:
         links = None
     return links
@@ -160,7 +162,7 @@ def get_orenburg():
     for sou in soup:
         sou = sou.find('a', class_='item_link')
         if sou != None:
-            links.append('https://orenburg.arbitr.ru' + sou.get('href'))
+            links.append({"link":'https://orenburg.arbitr.ru' + sou.get('href'), "name": sou.get_text()})
     for link in links:
         people.append(parser_person(link, 'https://orenburg.arbitr.ru/'))
     return people
@@ -210,7 +212,8 @@ def parser():
         for person_link in people_links:
             if person_link != None:
                 person = parser_person(person_link, 'https://ipc.arbitr.ru/')
-                people.append(person)
+                if person != 1:
+                    people.append(person)
         people.extend(get_orenburg())
         log.debug("The script stops working")
         return people
